@@ -1,5 +1,5 @@
 package Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes;
-$Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes::VERSION = '0.108';
+$Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes::VERSION = '0.109';
 # ABSTRACT: Generate valid CPAN::Changes Changelogs from git
 
 use v5.10.1;
@@ -36,7 +36,7 @@ has tag_regexp => (
     is      => 'ro',
     isa     => 'CoercedRegexpRef',
     coerce  => 1,
-    default => 'v?(\d+\.\d+)',
+    default => 'v?(\d+\.\d+(_\d+)?)'
 );
 
 
@@ -378,8 +378,8 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Ioan Rogers Alexandr Tuomas Voß Bell Bhadoria Ciornii Doug Jakob Jormola
-Retout Shantanu Tim
+=for :stopwords Ioan Rogers Alexandr Retout Shantanu Tim Tuomas Voss Bell Bhadoria Ciornii
+Doug Hare Jakob Jormola Lisa
 
 =head1 NAME
 
@@ -387,7 +387,7 @@ Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes - Generate valid CPAN::Chan
 
 =head1 VERSION
 
-version 0.108
+version 0.109
 
 =head1 SYNOPSIS
 
@@ -466,7 +466,7 @@ web interface at L<https://github.com/ioanrogers/Dist-Zilla-Plugin-ChangelogFrom
 
 =head1 AVAILABILITY
 
-The project homepage is L<http://metacpan.org/release/Dist-Zilla-Plugin-ChangelogFromGit-CPAN-Changes/>.
+The project homepage is L<http://search.cpan.org/dist/Dist-Zilla-Plugin-ChangelogFromGit-CPAN-Changes/>.
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
@@ -483,7 +483,7 @@ Ioan Rogers <ioanr@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ioan Rogers.
+This software is copyright (c) 2016 by Ioan Rogers.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
